RiceDecoder

Struct RiceDecoder 

pub struct RiceDecoder { /* private fields */ }
Rice-Golomb decoder for the Safe Browsing API

In Rice encoding, each number n is encoded as q and r where n = (q << k) + r. k is the Rice parameter (0..32).

The quotient q is encoded in unary: a sequence of q ones followed by a zero. The remainder r is encoded as a k-bit unsigned integer.

Implementations

Source

impl RiceDecoder

pub fn new(k: u32) -> Self

Create a new Rice decoder with the given parameter k

pub fn read_value(&self, bit_reader: &mut BitReader<'_>) -> Result<u32>

Read and decode a single value from the bit stream