pub struct RiceDecoder { /* private fields */ }Expand description
Rice-Golomb decoder for the Safe Browsing API
In Rice encoding, each number n is encoded as q and r where n = (q << k) + r. k is the Rice parameter (0..32).
The quotient q is encoded in unary: a sequence of q ones followed by a zero. The remainder r is encoded as a k-bit unsigned integer.
Implementations